@@ -45,7 +45,7 @@ describe "mariadb service is started" do
 end
 
 describe "mariadb is responsive" do
-  describe command("echo '\\s' | mysql") do
+  describe command("echo '\\s' | mysql --ssl=off") do
     its(:exit_status) { should eq 0 }
     its(:stdout) { should match (/Server:\s+MariaDB/) }
   end
